API Reference
=============

PagedList Class
---------------

.. automodule:: paged_list.paged_list
   :members:
   :undoc-members:
   :show-inheritance:

Main Module
-----------

.. automodule:: paged_list.main
   :members:
   :undoc-members:
   :show-inheritance:
